@@ -14,11 +14,9 @@ readFactivaXML <- readXML(spec = list(
     id = list("function", function(node) {
               str <- gsub("^distdoc:archive/ArchiveDoc::Article/", "",
                           xml_text(xml_find_all(node, ".//reference")))
-              # Extract useful information: origin, date, and two last characters to avoid collisions
-              m <- regmatches(str, regexec("^([A-Za-z]+)0*[1-9][0-9]([0-9][0-9][0-3][0-9][0-3][0-9]).*([A-Za-z0-9]{2})$", str))[[1]]
               # If extraction failed for some reason, make sure we return a unique identifier
-              if(length(m) == 4)
-                  paste(toupper(m[2]), "-", m[3], "-", m[4], sep="")
+              if(length(str) > 0 && nchar(str) > 0)
+                  str
               else
                   paste(sample(LETTERS, 10), collapse="")
     }),
@@ -39,6 +37,13 @@ readFactivaXML <- readXML(spec = list(
                     else
                         character(0)
     }),
+    page = list("function", function(node) {
+                str <- xml_text(xml_find_all(node, ".//page"))
+                if(length(str) > 0)
+                    str
+                else
+                    NA
+    }),
     wordcount = list("function", function(node)
                      as.numeric(xml_text(xml_find_all(node, ".//wordCount")))),
     publisher = list("node", ".//publisherName"),
